from django.db import models
from django.forms import ModelForm, DateField, ChoiceField, RadioSelect, BooleanField
from django.contrib.admin.widgets import AdminDateWidget
from django.utils.html import format_html

from .models import Project, Volunteer, Extern, IFG, Library, TYPE_CHOICES,\
                    HonoraryCertificate, Travel, Email, Literature, List,\
                    BusinessCard
from .settings import DATAPROTECTION, FOERDERRICHTLINIEN, NUTZUNGSBEDINGUNGEN


class ProjectForm(ModelForm):

    # start = DateField(widget=AdminDateWidget())

    class Meta:
        model = Project
        exclude = ('pid', 'granted', 'granted_date', 'realname', 'email',\
                   'end_mail_send', 'status', 'persons')
        widgets = {'start': AdminDateWidget(),
                   'end': AdminDateWidget(),}

class ExternForm(ModelForm):

    choice = ChoiceField(choices=TYPE_CHOICES.items(), widget=RadioSelect,
                         label='Was möchtest Du beantragen?')

    check = BooleanField(required=True,
                         label=format_html("Ich stimme den <a href='{}'>Datenschutzbestimmungen</a> und den <a href='{}'>Förderrichtlinen</a> zu",
                         DATAPROTECTION, FOERDERRICHTLINIEN))

    class Meta:
        model = Extern
        exclude = ('granted', 'granted_date', 'survey_mail_send', 'service_id')

INTERN_CHOICES = {'PRO': 'Projektsteckbrief',
                  'HON': 'Ehrenamtsbescheinigung, Akkreditierung oder Redaktionsbestätigung',
                  'TRAV': 'Reisekostenerstattung'}

class InternForm(ModelForm):
    choice = ChoiceField(choices = INTERN_CHOICES.items(), widget=RadioSelect,
                         label = 'Was möchtest Du eingeben?')

    class Meta:
        model = Volunteer
        exclude = ('granted', 'granted_date', 'survey_mail_send')

class TravelForm(ModelForm):
    # TODO: add some javascript to show/hide other-field
    class Meta:
        model = Travel
        exclude = ('granted', 'granted_date', 'survey_mail_send', 'realname', 'email',)
        widgets = {'checkin': AdminDateWidget(),
                   'checkout': AdminDateWidget(),}

class LibraryForm(ModelForm):

    class Meta:
        model = Library
        fields = ['cost', 'library', 'duration', 'notes']

class IFGForm(ModelForm):
    class Meta:
        model = IFG
        fields = ['cost', 'url', 'notes']

class HonoraryCertificateForm(ModelForm):
    class Meta:
        model = HonoraryCertificate
        fields = ['request_url', 'project']

class LiteratureForm(ModelForm):
    class Meta:
        model = Literature
        fields = ['cost', 'info', 'source', 'notes']

class EmailForm(ModelForm):
    # TODO: add some javascript to show/hide other-field
    check = BooleanField(required=True,
                         label=format_html("Ich stimme den <a href='{}'>Nutzungsbedingungen</a> zu",
                         NUTZUNGSBEDINGUNGEN))

    class Meta:
        model = Email
        fields = ['domain', 'address', 'other']

class BusinessCardForm(ModelForm):
    class Meta:
        model = BusinessCard
        fields = ['project', 'data', 'variant', 'sent_to']

class ListForm(ModelForm):
    class Meta:
        model = List
        fields = ['domain', 'address']
